@@ -92,7 +92,6 @@ class ezfuc(object):
                 res_text = ex[1](res_text)
                 return res_text
 
-
         if ex == 'xpath':
             from lxml import etree
             try:
@@ -231,7 +230,6 @@ class ezfuc(object):
             text = text.replace(i, to_what)
         return text
 
-
     @staticmethod
     def random_ua():
         """
@@ -279,6 +277,28 @@ class ezfuc(object):
         rs = random.choice(user_agent_list)  # 201706  firefox14 chrome63 ie9 opera2
         return rs
 
+    @classmethod
+    def save_excel(self, resList, excel_name, title=""):
+        """
+        将列表数据保存到表格
+        :param excel_name:
+        :return:
+        """
+        import xlsxwriter
+        from tqdm import tqdm
+        workbook = xlsxwriter.Workbook(f"{excel_name}.xlsx")
+        sheet = workbook.add_worksheet('Sheet1')  # 创建一个sheet表格
+        if title:
+            resList.insert(0, title)
+        l = 0
+        for line in tqdm(resList, ascii=True, desc=excel_name):
+            r = 00
+            for i in line:
+                sheet.write(l, r, i)  # 一个一个将单元格数据写入
+                r = r + 1
+            l = l + 1
+        workbook.close()
+
 
 class format_time(object):
     """
@@ -336,11 +356,10 @@ class format_time(object):
     @property
     def h(self):
         return self.__time.strftime('%H')
-    
+
 
 class EmailSend(object):
 
-
     def __init__(self, email_host, email_port, email_pass):
         import logging
 
@@ -380,3 +399,4 @@ class EmailSend(object):
 
     def send_video_email(self):
         pass
+
